# R Project
#
# Janine Campbell
# Contact: janine.anne.campbell@gmail.com
#
# Date last modified: 17 NOVEMBER 2020
#
###############################################################################
# Before running the is code, follow these instructions
#     1. Save all files (R code files and .csv data files) in the same folder
#        on your computer
#     2. Change the working directory (line 31) to the folder where you have
#        saved the code and data
#     3. Code should then run
###############################################################################
#
###############################################################################
# Crisp Set Analysis with COMBINEDPISA data set
###############################################################################
#
#------------------------------------------------------------------------------
# Remove all objects surrently stored in active memory
#------------------------------------------------------------------------------
rm(list=ls(all=TRUE))
# rm means remove, and it can also be used for an individual condition/variable
#------------------------------------------------------------------------------
# Check / set working directory
#------------------------------------------------------------------------------
getwd()
# Check that working directory is correct.  To change use following code:
#setwd("/Users/janine/Desktop/DATA2")
options(prompt="R> ")
#------------------------------------------------------------------------------
# Save Script with an original name 
#------------------------------------------------------------------------------
#
#    *****Manually save script*****
#
#------------------------------------------------------------------------------
# Activate packages for session
#------------------------------------------------------------------------------
library(readr)
library(ggplot2)
library(ggpubr)
library(ggthemes)
#
#------------------------------------------------------------------------------
# Import xlxs file
#------------------------------------------------------------------------------
#
library(readxl)
library(sjPlot)
library(sjmisc)
library(jtools)
library(interactions)
library(dplyr)
library(ggplot2)
library(tibble)
library(ggrepel)
library(Hmisc)
#
# 
#******************************************************************************
# Analysis of POLICY variables grouped by OUTCOME ENABLING FACTROS  
#******************************************************************************
#
#
options("jtools-digits" = 4)
options(scipen = 999)
#
POLICY <- read_excel("POLICYPISA.xlsx")
head(POLICY)
POLICY <- POLICY[-c(67,68,69), ]
#
summary(POLICY$PISASCORE)
sd(POLICY$PISASCORE, na.rm = T)
#
cor.test(POLICY$GENINEQ, POLICY$PISASCORE) # -0.845, P<0.001
summary(POLICY$GENINEQ)
sd(POLICY$GENINEQ, na.rm = T)
#
cor.test(POLICY$HDI, POLICY$PISASCORE) # 0.788, P<0.001
summary(POLICY$HDI)
sd(POLICY$HDI, na.rm = T)
#
cor.test(POLICY$CUMEXP, POLICY$PISASCORE) # 0.418, P<0.001
summary(POLICY$CUMEXP)
sd(POLICY$CUMEXP, na.rm = T)
#
cor.test(POLICY$HOURS, POLICY$PISASCORE) # 0.025, P=0.774
summary(POLICY$HOURS)
sd(POLICY$HOURS, na.rm = T)
#
cor.test(POLICY$CLASS, POLICY$PISASCORE) # -0,451, P<0.001
summary(POLICY$CLASS)
sd(POLICY$CLASS, na.rm = T)
#
cor.test(POLICY$PUBLIC, POLICY$PISASCORE) # 0.075, P=0.378
summary(POLICY$PUBLIC)
sd(POLICY$PUBLIC, na.rm = T)
#
cor.test(POLICY$PRIEXP, POLICY$PISASCORE) # -0.444, P<0.001
summary(POLICY$PRIEXP)
sd(POLICY$PRIEXP, na.rm = T)
#
cor.test(POLICY$SALARY, POLICY$PISASCORE) # 0.567, P<0.001
summary(POLICY$SALARY)
sd(POLICY$SALARY, na.rm = T)
#
cor.test(POLICY$QUALS, POLICY$PISASCORE) # 0.483, P<0.001
summary(POLICY$QUALS)
sd(POLICY$QUALS, na.rm = T)
#
cor.test(POLICY$PDEV, POLICY$PISASCORE) # 0.237, P=0.004
summary(POLICY$PDEV)
sd(POLICY$PDEV, na.rm = T)
#
cor.test(POLICY$EXP, POLICY$PISASCORE) # -0.106, P=0.312
summary(POLICY$EXP)
sd(POLICY$EXP, na.rm = T)
#
cor.test(POLICY$INDUCT, POLICY$PISASCORE) # 0.037, P=0.726
summary(POLICY$INDUCT)
sd(POLICY$INDUCT, na.rm = T)
#
cor.test(POLICY$MENTOR, POLICY$PISASCORE) # 0.095, P=0.364
summary(POLICY$MENTOR)
sd(POLICY$MENTOR, na.rm = T)
#
cor.test(POLICY$NONCON, POLICY$PISASCORE) # 0.508, P<0.001
summary(POLICY$NONCON)
sd(POLICY$NONCON, na.rm = T)
#
# *****************************************************************************
# MODERATION BY GENDER EQUALITY
# *****************************************************************************
#
# Make HIGENEQ subset
HIGENEQ <- subset(POLICY, HIGENEQ == 1)
#
summary(HIGENEQ$PISASCORE)
sd(HIGENEQ$PISASCORE)
#
cor.test(HIGENEQ$GENINEQ, HIGENEQ$PISASCORE) # -0.149, P=0.176
summary(HIGENEQ$GENINEQ)
sd(HIGENEQ$GENINEQ, na.rm = T)
#
cor.test(HIGENEQ$HDI, HIGENEQ$PISASCORE) # 0.364, P<0.001
summary(HIGENEQ$HDI)
sd(HIGENEQ$HDI, na.rm = T)
#
cor.test(HIGENEQ$CUMEXP, HIGENEQ$PISASCORE) # 0.027, P=0.814
summary(HIGENEQ$CUMEXP)
sd(HIGENEQ$CUMEXP, na.rm = T)
#
cor.test(HIGENEQ$HOURS, HIGENEQ$PISASCORE) # 0.117, P=0.291
summary(HIGENEQ$HOURS)
sd(HIGENEQ$HOURS, na.rm = T)
#
cor.test(HIGENEQ$CLASS, HIGENEQ$PISASCORE) # 0.498, P<0.001
summary(HIGENEQ$CLASS)
sd(HIGENEQ$CLASS, na.rm = T)
#
cor.test(HIGENEQ$PUBLIC, HIGENEQ$PISASCORE) # -0.142, P=0.206
summary(HIGENEQ$PUBLIC)
sd(HIGENEQ$PUBLIC, na.rm = T)
#
cor.test(HIGENEQ$PRIEXP, HIGENEQ$PISASCORE) # 0.163, P=0.162
summary(HIGENEQ$PRIEXP)
sd(HIGENEQ$PRIEXP, na.rm = T)
#
cor.test(HIGENEQ$SALARY, HIGENEQ$PISASCORE) # 0.334, P=0.007
summary(HIGENEQ$SALARY)
sd(HIGENEQ$SALARY, na.rm = T)
#
cor.test(HIGENEQ$QUALS, HIGENEQ$PISASCORE) # 0.396, P=0.001
summary(HIGENEQ$QUALS)
sd(HIGENEQ$QUALS, na.rm = T)
#
cor.test(HIGENEQ$PDEV, HIGENEQ$PISASCORE) # 0.300, P=0.006
summary(HIGENEQ$PDEV)
sd(HIGENEQ$PDEV, na.rm = T)
#
cor.test(HIGENEQ$EXP, HIGENEQ$PISASCORE) # -0.415, P<0.001
summary(HIGENEQ$EXP)
sd(HIGENEQ$EXP, na.rm = T)
#
cor.test(HIGENEQ$INDUCT, HIGENEQ$PISASCORE) # 0.324, P=0.011
summary(HIGENEQ$INDUCT)
sd(HIGENEQ$INDUCT, na.rm = T)
#
cor.test(HIGENEQ$MENTOR, HIGENEQ$PISASCORE) # 0.628, P<0.001
summary(HIGENEQ$MENTOR)
sd(HIGENEQ$MENTOR, na.rm = T)
#
cor.test(HIGENEQ$NONCON, HIGENEQ$PISASCORE) # 0.255, P=0.056
summary(HIGENEQ$NONCON)
sd(HIGENEQ$NONCON, na.rm = T)
#
#
# Make notHIGENEQ subset
notHIGENEQ <- subset(POLICY, HIGENEQ == 0)
#
summary(notHIGENEQ$PISASCORE)
sd(notHIGENEQ$PISASCORE)
#
cor.test(notHIGENEQ$GENINEQ, notHIGENEQ$PISASCORE) # -0.781, P<0.001
summary(notHIGENEQ$GENINEQ)
sd(notHIGENEQ$GENINEQ, na.rm = T)
#
cor.test(notHIGENEQ$HDI, notHIGENEQ$PISASCORE) # 0.599 P<0.001
summary(notHIGENEQ$HDI)
sd(notHIGENEQ$HDI, na.rm = T)
#
cor.test(notHIGENEQ$CUMEXP, notHIGENEQ$PISASCORE) # 0.549, P=0.003
summary(notHIGENEQ$CUMEXP)
sd(notHIGENEQ$CUMEXP, na.rm = T)
#
cor.test(notHIGENEQ$HOURS, notHIGENEQ$PISASCORE) # -0.028, P=0.846
summary(notHIGENEQ$HOURS)
sd(notHIGENEQ$HOURS, na.rm = T)
#
cor.test(notHIGENEQ$CLASS, notHIGENEQ$PISASCORE) # -0,426, P<0.001
summary(notHIGENEQ$CLASS)
sd(notHIGENEQ$CLASS, na.rm = T)
#
cor.test(notHIGENEQ$PUBLIC, notHIGENEQ$PISASCORE) # 0.430, P<0.001
summary(notHIGENEQ$PUBLIC)
sd(notHIGENEQ$PUBLIC, na.rm = T)
#
cor.test(notHIGENEQ$PRIEXP, notHIGENEQ$PISASCORE) # -0.820, P<0.001
summary(notHIGENEQ$PRIEXP)
sd(notHIGENEQ$PRIEXP, na.rm = T)
#
cor.test(notHIGENEQ$SALARY, notHIGENEQ$PISASCORE) # 0.243, P=0.136
summary(notHIGENEQ$SALARY)
sd(notHIGENEQ$SALARY, na.rm = T)
#
cor.test(notHIGENEQ$QUALS, notHIGENEQ$PISASCORE) # 0.430, P=0.001
summary(notHIGENEQ$QUALS)
sd(notHIGENEQ$QUALS, na.rm = T)
#
cor.test(notHIGENEQ$PDEV, notHIGENEQ$PISASCORE) # 0.108, P=0.399
summary(notHIGENEQ$PDEV)
sd(notHIGENEQ$PDEV, na.rm = T)
#
cor.test(notHIGENEQ$EXP, notHIGENEQ$PISASCORE) # 0.279, P=0.116
summary(notHIGENEQ$EXP)
sd(notHIGENEQ$EXP, na.rm = T)
#
cor.test(notHIGENEQ$INDUCT, notHIGENEQ$PISASCORE) # 0.164, P=0.361
summary(notHIGENEQ$INDUCT)
sd(notHIGENEQ$INDUCT, na.rm = T)
#
cor.test(notHIGENEQ$MENTOR, notHIGENEQ$PISASCORE) # -0.556, P<0.001
summary(notHIGENEQ$MENTOR)
sd(notHIGENEQ$MENTOR, na.rm = T)
#
cor.test(notHIGENEQ$NONCON, notHIGENEQ$PISASCORE) # 0.422, P=0.020
summary(notHIGENEQ$NONCON)
sd(notHIGENEQ$NONCON, na.rm = T)
#
library(effsize)
cohen.d(PISASCORE~HIGENEQ, POLICY)
t.test(PISASCORE~HIGENEQ, POLICY)
summary(HIGENEQ$PISASCORE) #N=84
summary(notHIGENEQ$PISASCORE) #N=63
#
cohen.d(GENINEQ~HIGENEQ, POLICY)
t.test(GENINEQ~HIGENEQ, POLICY)
summary(HIGENEQ$GENINEQ) #N=84
summary(notHIGENEQ$GENINEQ) #N=63
#
cohen.d(HDI~HIGENEQ, POLICY)
t.test(HDI~HIGENEQ, POLICY)
summary(HIGENEQ$HDI) #N=84
summary(notHIGENEQ$HDI) #N=63
#
cohen.d(CUMEXP~HIGENEQ, POLICY)
t.test(CUMEXP~HIGENEQ, POLICY)
summary(HIGENEQ$CUMEXP) #N=81
summary(notHIGENEQ$CUMEXP) #N=27
#
cohen.d(HOURS~HIGENEQ, POLICY)
t.test(HOURS~HIGENEQ, POLICY)
summary(HIGENEQ$HOURS) #N=84
summary(notHIGENEQ$HOURS) #N=51
#
cohen.d(CLASS~HIGENEQ, POLICY)
t.test(CLASS~HIGENEQ, POLICY)
summary(HIGENEQ$CLASS) #N=84
summary(notHIGENEQ$CLASS) #N=63
#
cohen.d(PUBLIC~HIGENEQ, POLICY)
t.test(PUBLIC~HIGENEQ, POLICY)
summary(HIGENEQ$PUBLIC) #N=81
summary(notHIGENEQ$PUBLIC) #N=60
#
cohen.d(PRIEXP~HIGENEQ, POLICY)
t.test(PRIEXP~HIGENEQ, POLICY)
summary(HIGENEQ$PRIEXP) #N=75
summary(notHIGENEQ$PRIEXP) #N=30
#
cohen.d(SALARY~HIGENEQ, POLICY)
t.test(SALARY~HIGENEQ, POLICY)
summary(HIGENEQ$SALARY) #N=63
summary(notHIGENEQ$SALARY) #N=39
#
cohen.d(QUALS~HIGENEQ, POLICY)
t.test(QUALS~HIGENEQ, POLICY)
summary(HIGENEQ$QUALS) #N=84
summary(notHIGENEQ$QUALS) #N=54
#
cohen.d(PDEV~HIGENEQ, POLICY)
t.test(PDEV~HIGENEQ, POLICY)
summary(HIGENEQ$PDEV) #N=84
summary(notHIGENEQ$PDEV) #N=63
#
cohen.d(EXP~HIGENEQ, POLICY)
t.test(EXP~HIGENEQ, POLICY)
summary(HIGENEQ$EXP) #N=60
summary(notHIGENEQ$EXP) #N=33
#
cohen.d(INDUCT~HIGENEQ, POLICY)
t.test(INDUCT~HIGENEQ, POLICY)
summary(HIGENEQ$INDUCT) #N=60
summary(notHIGENEQ$INDUCT) #N=33
#
cohen.d(MENTOR~HIGENEQ, POLICY)
t.test(MENTOR~HIGENEQ, POLICY)
summary(HIGENEQ$MENTOR) #N=60
summary(notHIGENEQ$MENTOR) #N=33
#
cohen.d(NONCON~HIGENEQ, POLICY)
t.test(NONCON~HIGENEQ, POLICY)
summary(HIGENEQ$NONCON) #N=57
summary(notHIGENEQ$NONCON) #N=30
#
# *****************************************************************************
# MODERATION BY HUMAN DEVELOPMENT INDEX
# *****************************************************************************
#
# Make HIHDI subset
HIHDI <- subset(POLICY, HIHDI == 1)
#
summary(HIHDI$PISASCORE)
sd(HIHDI$PISASCORE)
#
cor.test(HIHDI$GENINEQ, HIHDI$PISASCORE) # -0.107, P=.381
summary(HIHDI$GENINEQ)
sd(HIHDI$GENINEQ, na.rm = T)
#
cor.test(HIHDI$HDI, HIHDI$PISASCORE) # 0.136, P=0.2666
summary(HIHDI$HDI)
sd(HIHDI$HDI, na.rm = T)
#
cor.test(HIHDI$CUMEXP, HIHDI$PISASCORE) # -0.173, P=.155
summary(HIHDI$CUMEXP)
sd(HIHDI$CUMEXP, na.rm = T)
#
cor.test(HIHDI$HOURS, HIHDI$PISASCORE) # 0.105, P=0.389
summary(HIHDI$HOURS)
sd(HIHDI$HOURS, na.rm = T)
#
cor.test(HIHDI$CLASS, HIHDI$PISASCORE) # 0.539, P<0.001
summary(HIHDI$CLASS)
sd(HIHDI$CLASS, na.rm = T)
#
cor.test(HIHDI$PUBLIC, HIHDI$PISASCORE) # -0.079, P=0.530
summary(HIHDI$PUBLIC)
sd(HIHDI$PUBLIC, na.rm = T)
#
cor.test(HIHDI$PRIEXP, HIHDI$PISASCORE) # 0.196, P=0.125
summary(HIHDI$PRIEXP)
sd(HIHDI$PRIEXP, na.rm = T)
#
cor.test(HIHDI$SALARY, HIHDI$PISASCORE) # -0.025, P=0.860
summary(HIHDI$SALARY)
sd(HIHDI$SALARY, na.rm = T)
#
cor.test(HIHDI$QUALS, HIHDI$PISASCORE) # 0.515, P<0.001
summary(HIHDI$QUALS)
sd(HIHDI$QUALS, na.rm = T)
#
cor.test(HIHDI$PDEV, HIHDI$PISASCORE) # 0.103, P=0.399
summary(HIHDI$PDEV)
sd(HIHDI$PDEV, na.rm = T)
#
cor.test(HIHDI$EXP, HIHDI$PISASCORE) # -0.440, P=0.001
summary(HIHDI$EXP)
sd(HIHDI$EXP, na.rm = T)
#
cor.test(HIHDI$INDUCT, HIHDI$PISASCORE) # 0.328, P=0.019
summary(HIHDI$INDUCT)
sd(HIHDI$INDUCT, na.rm = T)
#
cor.test(HIHDI$MENTOR, HIHDI$PISASCORE) # 0.649, P<0.001
summary(HIHDI$MENTOR)
sd(HIHDI$MENTOR, na.rm = T)
#
cor.test(HIHDI$NONCON, HIHDI$PISASCORE) # 0.383, P=0.007
summary(HIHDI$NONCON)
sd(HIHDI$NONCON, na.rm = T)
#
#
# Make notHIHDI subset
notHIHDI <- subset(POLICY, HIHDI == 0)
#
summary(notHIHDI$PISASCORE)
sd(notHIHDI$PISASCORE)
#
cor.test(notHIHDI$GENINEQ, notHIHDI$PISASCORE) # -0.805, P<0.001
summary(notHIHDI$GENINEQ)
sd(notHIHDI$GENINEQ, na.rm = T)
#
cor.test(notHIHDI$HDI, notHIHDI$PISASCORE) # 0.664 P<0.001
summary(notHIHDI$HDI)
sd(notHIHDI$HDI, na.rm = T)
#
cor.test(notHIHDI$CUMEXP, notHIHDI$PISASCORE) # 0.724, P<0.001
summary(notHIHDI$CUMEXP)
sd(notHIHDI$CUMEXP, na.rm = T)
#
cor.test(notHIHDI$HOURS, notHIHDI$PISASCORE) # -0.096, P=0.445
summary(notHIHDI$HOURS)
sd(notHIHDI$HOURS, na.rm = T)
#
cor.test(notHIHDI$CLASS, notHIHDI$PISASCORE) # -0,499, P<0.001
summary(notHIHDI$CLASS)
sd(notHIHDI$CLASS, na.rm = T)
#
cor.test(notHIHDI$PUBLIC, notHIHDI$PISASCORE) # 0.421, P<0.001
summary(notHIHDI$PUBLIC)
sd(notHIHDI$PUBLIC, na.rm = T)
#
cor.test(notHIHDI$PRIEXP, notHIHDI$PISASCORE) # -0.764, P<0.001
summary(notHIHDI$PRIEXP)
sd(notHIHDI$PRIEXP, na.rm = T)
#
cor.test(notHIHDI$SALARY, notHIHDI$PISASCORE) # 0.230, P=0.116
summary(notHIHDI$SALARY)
sd(notHIHDI$SALARY, na.rm = T)
#
cor.test(notHIHDI$QUALS, notHIHDI$PISASCORE) # 0.489, P<0.001
summary(notHIHDI$QUALS)
sd(notHIHDI$QUALS, na.rm = T)
#
cor.test(notHIHDI$PDEV, notHIHDI$PISASCORE) # 0.021, P=0.857
summary(notHIHDI$PDEV)
sd(notHIHDI$PDEV, na.rm = T)
#
cor.test(notHIHDI$EXP, notHIHDI$PISASCORE) # 0.606, P<0.001
summary(notHIHDI$EXP)
sd(notHIHDI$EXP, na.rm = T)
#
cor.test(notHIHDI$INDUCT, notHIHDI$PISASCORE) # -0.330, P=0.033
summary(notHIHDI$INDUCT)
sd(notHIHDI$INDUCT, na.rm = T)
#
cor.test(notHIHDI$MENTOR, notHIHDI$PISASCORE) # -0.658, P<0.001
summary(notHIHDI$MENTOR)
sd(notHIHDI$MENTOR, na.rm = T)
#
cor.test(notHIHDI$NONCON, notHIHDI$PISASCORE) # 0.442, P=0.005
summary(notHIHDI$NONCON)
sd(notHIHDI$NONCON, na.rm = T)
#
cohen.d(PISASCORE~HIHDI, POLICY)
t.test(PISASCORE~HIHDI, POLICY)
summary(HIHDI$PISASCORE) #N=69
summary(notHIHDI$PISASCORE) #N=78
#
cohen.d(GENINEQ~HIHDI, POLICY)
t.test(GENINEQ~HIHDI, POLICY)
summary(HIHDI$GENINEQ) #N=69
summary(notHIHDI$GENINEQ) #N=78
#
cohen.d(HDI~HIHDI, POLICY)
t.test(HDI~HIHDI, POLICY)
summary(HIHDI$HDI) #N=69
summary(notHIHDI$HDI) #N=78
#
cohen.d(CUMEXP~HIHDI, POLICY)
t.test(CUMEXP~HIHDI, POLICY)
summary(HIHDI$CUMEXP) #N=69
summary(notHIHDI$CUMEXP) #N=39
#
cohen.d(HOURS~HIHDI, POLICY)
t.test(HOURS~HIHDI, POLICY)
summary(HIHDI$HOURS) #N=69
summary(notHIHDI$HOURS) #N=66
#
cohen.d(CLASS~HIHDI, POLICY)
t.test(CLASS~HIHDI, POLICY)
summary(HIHDI$CLASS) #N=69
summary(notHIHDI$CLASS) #N=78
#
cohen.d(PUBLIC~HIHDI, POLICY)
t.test(PUBLIC~HIHDI, POLICY)
summary(HIHDI$PUBLIC) #N=66
summary(notHIHDI$PUBLIC) #N=75
#
cohen.d(PRIEXP~HIHDI, POLICY)
t.test(PRIEXP~HIHDI, POLICY)
summary(HIHDI$PRIEXP) #N=63
summary(notHIHDI$PRIEXP) #N=42
#
cohen.d(SALARY~HIHDI, POLICY)
t.test(SALARY~HIHDI, POLICY)
summary(HIHDI$SALARY) #N=54
summary(notHIHDI$SALARY) #N=48
#
cohen.d(QUALS~HIHDI, POLICY)
t.test(QUALS~HIHDI, POLICY)
summary(HIHDI$QUALS) #N=69
summary(notHIHDI$QUALS) #N=69
#
cohen.d(PDEV~HIHDI, POLICY)
t.test(PDEV~HIHDI, POLICY)
summary(HIHDI$PDEV) #N=69
summary(notHIHDI$PDEV) #N=78
#
cohen.d(EXP~HIHDI, POLICY)
t.test(EXP~HIHDI, POLICY)
summary(HIHDI$EXP) #N=51
summary(notHIHDI$EXP) #N=42
#
cohen.d(INDUCT~HIHDI, POLICY)
t.test(INDUCT~HIHDI, POLICY)
summary(HIHDI$INDUCT) #N=51
summary(notHIHDI$INDUCT) #N=42
#
cohen.d(MENTOR~HIHDI, POLICY)
t.test(MENTOR~HIHDI, POLICY)
summary(HIHDI$MENTOR) #N=51
summary(notHIHDI$MENTOR) #N=42
#
cohen.d(NONCON~HIHDI, POLICY)
t.test(NONCON~HIHDI, POLICY)
summary(HIHDI$NONCON) #N=48
summary(notHIHDI$NONCON) #N=39
#
#
# *****************************************************************************
# MODERATION BY INCOME EQUALITY INDEX
# *****************************************************************************
#
# Make HIINCEQ subset
HIINCEQ <- subset(POLICY, HIINCEQ == 1)
#
summary(HIINCEQ$PISASCORE)
sd(HIINCEQ$PISASCORE)
#
cor.test(HIINCEQ$CUMEXP, HIINCEQ$PISASCORE) # 0.252, P=0.033
summary(HIINCEQ$CUMEXP)
sd(HIINCEQ$CUMEXP, na.rm = T)
#
cor.test(HIINCEQ$HOURS, HIINCEQ$PISASCORE) # 0.252, P=0.033
summary(HIINCEQ$HOURS)
sd(HIINCEQ$HOURS, na.rm = T)
#
cor.test(HIINCEQ$CLASS, HIINCEQ$PISASCORE) # 0.018, P=0.877
summary(HIINCEQ$CLASS)
sd(HIINCEQ$CLASS, na.rm = T)
#
cor.test(HIINCEQ$PUBLIC, HIINCEQ$PISASCORE) # -0.236, P=0.046
summary(HIINCEQ$PUBLIC)
sd(HIINCEQ$PUBLIC, na.rm = T)
#
cor.test(HIINCEQ$PRIEXP, HIINCEQ$PISASCORE) # -0.050, P=0.688
summary(HIINCEQ$PRIEXP)
sd(HIINCEQ$PRIEXP, na.rm = T)
#
cor.test(HIINCEQ$SALARY, HIINCEQ$PISASCORE) # 0.606, P<0.001
summary(HIINCEQ$SALARY)
sd(HIINCEQ$SALARY, na.rm = T)
#
cor.test(HIINCEQ$QUALS, HIINCEQ$PISASCORE) # 0.268, P<0.020
summary(HIINCEQ$QUALS)
sd(HIINCEQ$QUALS, na.rm = T)
#
cor.test(HIINCEQ$PDEV, HIINCEQ$PISASCORE) # -0.010, P=0.928
summary(HIINCEQ$PDEV)
sd(HIINCEQ$PDEV, na.rm = T)
#
cor.test(HIINCEQ$EXP, HIINCEQ$PISASCORE) # 0.028, P=0.835
summary(HIINCEQ$EXP)
sd(HIINCEQ$EXP, na.rm = T)
#
cor.test(HIINCEQ$INDUCT, HIINCEQ$PISASCORE) # -0.112, P=0.405
summary(HIINCEQ$INDUCT)
sd(HIINCEQ$INDUCT, na.rm = T)
#
cor.test(HIINCEQ$MENTOR, HIINCEQ$PISASCORE) # 0.370, P<0.005
summary(HIINCEQ$MENTOR)
sd(HIINCEQ$MENTOR, na.rm = T)
#
cor.test(HIINCEQ$NONCON, HIINCEQ$PISASCORE) # -0.099, P=0.475
summary(HIINCEQ$NONCON)
sd(HIINCEQ$NONCON, na.rm = T)
#
#
# Make notHIINCEQ subset
notHIINCEQ <- subset(POLICY, HIINCEQ == 0)
#
summary(notHIINCEQ$PISASCORE)
sd(notHIINCEQ$PISASCORE)
#
cor.test(notHIINCEQ$CUMEXP, notHIINCEQ$PISASCORE) # 0.512, P=0.001
summary(notHIINCEQ$CUMEXP)
sd(notHIINCEQ$CUMEXP, na.rm = T)
#
cor.test(notHIINCEQ$HOURS, notHIINCEQ$PISASCORE) # 0.121, P=0.347
summary(notHIINCEQ$HOURS)
sd(notHIINCEQ$HOURS, na.rm = T)
#
cor.test(notHIINCEQ$CLASS, notHIINCEQ$PISASCORE) # -0,412, P<0.001
summary(notHIINCEQ$CLASS)
sd(notHIINCEQ$CLASS, na.rm = T)
#
cor.test(notHIINCEQ$PUBLIC, notHIINCEQ$PISASCORE) # 0.283, P=0.018
summary(notHIINCEQ$PUBLIC)
sd(notHIINCEQ$PUBLIC, na.rm = T)
#
cor.test(notHIINCEQ$PRIEXP, notHIINCEQ$PISASCORE) # -0.591, P<0.001
summary(notHIINCEQ$PRIEXP)
sd(notHIINCEQ$PRIEXP, na.rm = T)
#
cor.test(notHIINCEQ$SALARY, notHIINCEQ$PISASCORE) # 0.581, P<0.001
summary(notHIINCEQ$SALARY)
sd(notHIINCEQ$SALARY, na.rm = T)
#
cor.test(notHIINCEQ$QUALS, notHIINCEQ$PISASCORE) # 0.459, P<0.001
summary(notHIINCEQ$QUALS)
sd(notHIINCEQ$QUALS, na.rm = T)
#
cor.test(notHIINCEQ$PDEV, notHIINCEQ$PISASCORE) # 0.342, P=0.004
summary(notHIINCEQ$PDEV)
sd(notHIINCEQ$PDEV, na.rm = T)
#
cor.test(notHIINCEQ$EXP, notHIINCEQ$PISASCORE) # -0.080, P=0.642
summary(notHIINCEQ$EXP)
sd(notHIINCEQ$EXP, na.rm = T)
#
cor.test(notHIINCEQ$INDUCT, notHIINCEQ$PISASCORE) # 0.353, P=0.035
summary(notHIINCEQ$INDUCT)
sd(notHIINCEQ$INDUCT, na.rm = T)
#
cor.test(notHIINCEQ$MENTOR, notHIINCEQ$PISASCORE) # 0.030, P=0.861
summary(notHIINCEQ$MENTOR)
sd(notHIINCEQ$MENTOR, na.rm = T)
#
cor.test(notHIINCEQ$NONCON, notHIINCEQ$PISASCORE) # 0.672, P<0.001
summary(notHIINCEQ$NONCON)
sd(notHIINCEQ$NONCON, na.rm = T)
#
cohen.d(PISASCORE~HIINCEQ, POLICY)
t.test(PISASCORE~HIINCEQ, POLICY)
summary(HIINCEQ$PISASCORE) #N=78
summary(notHIINCEQ$PISASCORE) #N=69
#
cohen.d(CUMEXP~HIINCEQ, POLICY)
t.test(CUMEXP~HIINCEQ, POLICY)
summary(HIINCEQ$CUMEXP) #N=72
summary(notHIINCEQ$CUMEXP) #N=36
#
cohen.d(HOURS~HIINCEQ, POLICY)
t.test(HOURS~HIINCEQ, POLICY)
summary(HIINCEQ$HOURS) #N=72
summary(notHIINCEQ$HOURS) #N=63
#
cohen.d(CLASS~HIINCEQ, POLICY)
t.test(CLASS~HIINCEQ, POLICY)
summary(HIINCEQ$CLASS) #N=78
summary(notHIINCEQ$CLASS) #N=69
#
cohen.d(PUBLIC~HIINCEQ, POLICY)
t.test(PUBLIC~HIINCEQ, POLICY)
summary(HIINCEQ$PUBLIC) #N=72
summary(notHIINCEQ$PUBLIC) #N=69
#
cohen.d(PRIEXP~HIINCEQ, POLICY)
t.test(PRIEXP~HIINCEQ, POLICY)
summary(HIINCEQ$PRIEXP) #N=66
summary(notHIINCEQ$PRIEXP) #N=39
#
cohen.d(SALARY~HIINCEQ, POLICY)
t.test(SALARY~HIINCEQ, POLICY)
summary(HIINCEQ$SALARY) #N=51
summary(notHIINCEQ$SALARY) #N=51
#
cohen.d(QUALS~HIINCEQ, POLICY)
t.test(QUALS~HIINCEQ, POLICY)
summary(HIINCEQ$QUALS) #N=75
summary(notHIINCEQ$QUALS) #N=63
#
cohen.d(PDEV~HIINCEQ, POLICY)
t.test(PDEV~HIINCEQ, POLICY)
summary(HIINCEQ$PDEV) #N=78
summary(notHIINCEQ$PDEV) #N=69
#
cohen.d(EXP~HIINCEQ, POLICY)
t.test(EXP~HIINCEQ, POLICY)
summary(HIINCEQ$EXP) #N=57
summary(notHIINCEQ$EXP) #N=36
#
cohen.d(INDUCT~HIINCEQ, POLICY)
t.test(INDUCT~HIINCEQ, POLICY)
summary(HIINCEQ$INDUCT) #N=57
summary(notHIINCEQ$INDUCT) #N=36
#
cohen.d(MENTOR~HIINCEQ, POLICY)
t.test(MENTOR~HIINCEQ, POLICY)
summary(HIINCEQ$MENTOR) #N=57
summary(notHIINCEQ$MENTOR) #N=36
#
cohen.d(NONCON~HIINCEQ, POLICY)
t.test(NONCON~HIINCEQ, POLICY)
summary(HIINCEQ$NONCON) #N=54
summary(notHIINCEQ$NONCON) #N=30
#
#
# *****************************************************************************
# MODERATION BY INDIVIDUALISM
# *****************************************************************************
#
# Make HIINDIV subset
HIINDIV <- subset(POLICY, HIINDIV == 1)
#
summary(HIINDIV$PISASCORE)
sd(HIINDIV$PISASCORE)
#
cor.test(HIINDIV$CUMEXP, HIINDIV$PISASCORE) # 0.156, P=.166
summary(HIINDIV$CUMEXP)
sd(HIINDIV$CUMEXP, na.rm = T)
#
cor.test(HIINDIV$HOURS, HIINDIV$PISASCORE) # -0.010, P=0.931
summary(HIINDIV$HOURS)
sd(HIINDIV$HOURS, na.rm = T)
#
cor.test(HIINDIV$CLASS, HIINDIV$PISASCORE) # -0.016, P=0.890
summary(HIINDIV$CLASS)
sd(HIINDIV$CLASS, na.rm = T)
#
cor.test(HIINDIV$PUBLIC, HIINDIV$PISASCORE) # -0.133, P=0.245
summary(HIINDIV$PUBLIC)
sd(HIINDIV$PUBLIC, na.rm = T)
#
cor.test(HIINDIV$PRIEXP, HIINDIV$PISASCORE) # -0.003, P=0.979
summary(HIINDIV$PRIEXP)
sd(HIINDIV$PRIEXP, na.rm = T)
#
cor.test(HIINDIV$SALARY, HIINDIV$PISASCORE) # 0.381, P=0.002
summary(HIINDIV$SALARY)
sd(HIINDIV$SALARY, na.rm = T)
#
cor.test(HIINDIV$QUALS, HIINDIV$PISASCORE) # 0.155, P=0.175
summary(HIINDIV$QUALS)
sd(HIINDIV$QUALS, na.rm = T)
#
cor.test(HIINDIV$PDEV, HIINDIV$PISASCORE) # 0.211, P=0.059
summary(HIINDIV$PDEV)
sd(HIINDIV$PDEV, na.rm = T)
#
cor.test(HIINDIV$EXP, HIINDIV$PISASCORE) # -0.148, P=0.260
summary(HIINDIV$EXP)
sd(HIINDIV$EXP, na.rm = T)
#
cor.test(HIINDIV$INDUCT, HIINDIV$PISASCORE) # -0.277, P=0.031
summary(HIINDIV$INDUCT)
sd(HIINDIV$INDUCT, na.rm = T)
#
cor.test(HIINDIV$MENTOR, HIINDIV$PISASCORE) # 0.216, P=0.010
summary(HIINDIV$MENTOR)
sd(HIINDIV$MENTOR, na.rm = T)
#
cor.test(HIINDIV$NONCON, HIINDIV$PISASCORE) # -0.095, P=0.480
summary(HIINDIV$NONCON)
sd(HIINDIV$NONCON, na.rm = T)
#
#
# Make notHIINDIV subset
notHIINDIV <- subset(POLICY, HIINDIV == 0)
#
summary(notHIINDIV$PISASCORE)
sd(notHIINDIV$PISASCORE)
#
#
cor.test(notHIINDIV$CUMEXP, notHIINDIV$PISASCORE) # 0.906, P<0.001
summary(notHIINDIV$CUMEXP)
sd(notHIINDIV$CUMEXP, na.rm = T)
#
cor.test(notHIINDIV$HOURS, notHIINDIV$PISASCORE) # 0.240, P=0.080
summary(notHIINDIV$HOURS)
sd(notHIINDIV$HOURS, na.rm = T)
#
cor.test(notHIINDIV$CLASS, notHIINDIV$PISASCORE) # -0.185, P=0.138
summary(notHIINDIV$CLASS)
sd(notHIINDIV$CLASS, na.rm = T)
#
cor.test(notHIINDIV$PUBLIC, notHIINDIV$PISASCORE) # 0.217, P=0.088
summary(notHIINDIV$PUBLIC)
sd(notHIINDIV$PUBLIC, na.rm = T)
#
cor.test(notHIINDIV$PRIEXP, notHIINDIV$PISASCORE) # -0.666, P<0.001
summary(notHIINDIV$PRIEXP)
sd(notHIINDIV$PRIEXP, na.rm = T)
#
cor.test(notHIINDIV$SALARY, notHIINDIV$PISASCORE) # 0.787, P<0.001
summary(notHIINDIV$SALARY)
sd(notHIINDIV$SALARY, na.rm = T)
#
cor.test(notHIINDIV$QUALS, notHIINDIV$PISASCORE) # 0.515, P<0.001
summary(notHIINDIV$QUALS)
sd(notHIINDIV$QUALS, na.rm = T)
#
cor.test(notHIINDIV$PDEV, notHIINDIV$PISASCORE) # 0.216, P=0.081
summary(notHIINDIV$PDEV)
sd(notHIINDIV$PDEV, na.rm = T)
#
cor.test(notHIINDIV$EXP, notHIINDIV$PISASCORE) # -0.127, P=0.481
summary(notHIINDIV$EXP)
sd(notHIINDIV$EXP, na.rm = T)
#
cor.test(notHIINDIV$INDUCT, notHIINDIV$PISASCORE) # 0.632, P<0.001
summary(notHIINDIV$INDUCT)
sd(notHIINDIV$INDUCT, na.rm = T)
#
cor.test(notHIINDIV$MENTOR, notHIINDIV$PISASCORE) # 0.305, P=0.084
summary(notHIINDIV$MENTOR)
sd(notHIINDIV$MENTOR, na.rm = T)
#
cor.test(notHIINDIV$NONCON, notHIINDIV$PISASCORE) # 0.658, P<0.001
summary(notHIINDIV$NONCON)
sd(notHIINDIV$NONCON, na.rm = T)
#
cohen.d(PISASCORE~HIINDIV, POLICY)
t.test(PISASCORE~HIINDIV, POLICY)
summary(HIINDIV$PISASCORE) #N=81
summary(notHIINDIV$PISASCORE) #N=66
#
#
cohen.d(CUMEXP~HIINDIV, POLICY)
t.test(CUMEXP~HIINDIV, POLICY)
summary(HIINDIV$CUMEXP) #N=81
summary(notHIINDIV$CUMEXP) #N=27
#
cohen.d(HOURS~HIINDIV, POLICY)
t.test(HOURS~HIINDIV, POLICY)
summary(HIINDIV$HOURS) #N=81
summary(notHIINDIV$HOURS) #N=54
#
cohen.d(CLASS~HIINDIV, POLICY)
t.test(CLASS~HIINDIV, POLICY)
summary(HIINDIV$CLASS) #N=81
summary(notHIINDIV$CLASS) #N=66
#
cohen.d(PUBLIC~HIINDIV, POLICY)
t.test(PUBLIC~HIINDIV, POLICY)
summary(HIINDIV$PUBLIC) #N=78
summary(notHIINDIV$PUBLIC) #N=63
#
cohen.d(PRIEXP~HIINDIV, POLICY)
t.test(PRIEXP~HIINDIV, POLICY)
summary(HIINDIV$PRIEXP) #N=78
summary(notHIINDIV$PRIEXP) #N=27
#
cohen.d(SALARY~HIINDIV, POLICY)
t.test(SALARY~HIINDIV, POLICY)
summary(HIINDIV$SALARY) #N=63
summary(notHIINDIV$SALARY) #N=39
#
cohen.d(QUALS~HIINDIV, POLICY)
t.test(QUALS~HIINDIV, POLICY)
summary(HIINDIV$QUALS) #N=78
summary(notHIINDIV$QUALS) #N=60
#
cohen.d(PDEV~HIINDIV, POLICY)
t.test(PDEV~HIINDIV, POLICY)
summary(HIINDIV$PDEV) #N=81
summary(notHIINDIV$PDEV) #N=66
#
cohen.d(EXP~HIINDIV, POLICY)
t.test(EXP~HIINDIV, POLICY)
summary(HIINDIV$EXP) #N=60
summary(notHIINDIV$EXP) #N=33
#
cohen.d(INDUCT~HIINDIV, POLICY)
t.test(INDUCT~HIINDIV, POLICY)
summary(HIINDIV$INDUCT) #N=60
summary(notHIINDIV$INDUCT) #N=33
#
cohen.d(MENTOR~HIINDIV, POLICY)
t.test(MENTOR~HIINDIV, POLICY)
summary(HIINDIV$MENTOR) #N=60
summary(notHIINDIV$MENTOR) #N=33
#
cohen.d(NONCON~HIINDIV, POLICY)
t.test(NONCON~HIINDIV, POLICY)
summary(HIINDIV$NONCON) #N=57
summary(notHIINDIV$NONCON) #N=30
#
#
#
#------------------------------------------------------------------------------
# Save Script
#------------------------------------------------------------------------------
#
#    *****Manually save script*****
#
#------------------------------------------------------------------------------
# Quit R
#------------------------------------------------------------------------------
q()


